EXPORTS
	??1CMdaBitmapRotator@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CMdaBitmapRotator::~CMdaBitmapRotator(void)
	??1CMdaBitmapScaler@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CMdaBitmapScaler::~CMdaBitmapScaler(void)
	??1CMdaImageBitmapToBitmapUtility@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CMdaImageBitmapToBitmapUtility::~CMdaImageBitmapToBitmapUtility(void)
	?CancelConvertL@CMdaImageBitmapToBitmapUtility@@UAEXXZ @ 4 NONAME ; public: virtual void __thiscall CMdaImageBitmapToBitmapUtility::CancelConvertL(void)
	?CancelConvertL@CMdaImageDataReadUtility@@UAEXXZ @ 5 NONAME ; public: virtual void __thiscall CMdaImageDataReadUtility::CancelConvertL(void)
	?CancelConvertL@CMdaImageDataWriteUtility@@UAEXXZ @ 6 NONAME ; public: virtual void __thiscall CMdaImageDataWriteUtility::CancelConvertL(void)
	?CancelRotation@CMdaBitmapRotator@@QAEXXZ @ 7 NONAME ; public: void __thiscall CMdaBitmapRotator::CancelRotation(void)
	?CancelScaling@CMdaBitmapScaler@@QAEXXZ @ 8 NONAME ; public: void __thiscall CMdaBitmapScaler::CancelScaling(void)
	?Close@CMdaImageUtility@@UAEXXZ @ 9 NONAME ; public: virtual void __thiscall CMdaImageUtility::Close(void)
	?ConvertL@CMdaImageBitmapToBitmapUtility@@UAEXAAVCFbsBitmap@@0H@Z @ 10 NONAME ; public: virtual void __thiscall CMdaImageBitmapToBitmapUtility::ConvertL(class CFbsBitmap &,class CFbsBitmap &,int)
	?ConvertL@CMdaImageBitmapToBitmapUtility@@UAEXAAVCFbsBitmap@@H@Z @ 11 NONAME ; public: virtual void __thiscall CMdaImageBitmapToBitmapUtility::ConvertL(class CFbsBitmap &,int)
	?ConvertL@CMdaImageDataReadUtility@@UAEXAAVCFbsBitmap@@0H@Z @ 12 NONAME ; public: virtual void __thiscall CMdaImageDataReadUtility::ConvertL(class CFbsBitmap &,class CFbsBitmap &,int)
	?ConvertL@CMdaImageDataReadUtility@@UAEXAAVCFbsBitmap@@H@Z @ 13 NONAME ; public: virtual void __thiscall CMdaImageDataReadUtility::ConvertL(class CFbsBitmap &,int)
	?ConvertL@CMdaImageDataWriteUtility@@UAEXAAVCFbsBitmap@@0H@Z @ 14 NONAME ; public: virtual void __thiscall CMdaImageDataWriteUtility::ConvertL(class CFbsBitmap &,class CFbsBitmap &,int)
	?ConvertL@CMdaImageDataWriteUtility@@UAEXAAVCFbsBitmap@@ABVTRect@@H@Z @ 15 NONAME ; public: virtual void __thiscall CMdaImageDataWriteUtility::ConvertL(class CFbsBitmap &,class TRect const &,int)
	?ConvertL@CMdaImageDataWriteUtility@@UAEXAAVCFbsBitmap@@H@Z @ 16 NONAME ; public: virtual void __thiscall CMdaImageDataWriteUtility::ConvertL(class CFbsBitmap &,int)
	?CreateL@CMdaImageBitmapToDescUtility@@QAEXAAVTDes8@@PAVTMdaClipFormat@@PAVTMdaPackage@@2@Z @ 17 NONAME ; public: void __thiscall CMdaImageBitmapToDescUtility::CreateL(class TDes8 &,class TMdaClipFormat *,class TMdaPackage *,class TMdaPackage *)
	?CreateL@CMdaImageBitmapToFileUtility@@QAEXABVTDesC16@@PAVTMdaClipFormat@@PAVTMdaPackage@@2@Z @ 18 NONAME ; public: void __thiscall CMdaImageBitmapToFileUtility::CreateL(class TDesC16 const &,class TMdaClipFormat *,class TMdaPackage *,class TMdaPackage *)
	?FrameCount@CMdaImageUtility@@UBEHXZ @ 19 NONAME ; public: virtual int __thiscall CMdaImageUtility::FrameCount(void)const 
	?FrameInfo@CMdaImageUtility@@UBEXHAAVTFrameInfo@@@Z @ 20 NONAME ; void CMdaImageUtility::FrameInfo(int, class TFrameInfo &) const
	?NewL@CMdaBitmapRotator@@SAPAV1@XZ @ 21 NONAME ; public: static class CMdaBitmapRotator * __cdecl CMdaBitmapRotator::NewL(void)
	?NewL@CMdaBitmapScaler@@SAPAV1@XZ @ 22 NONAME ; public: static class CMdaBitmapScaler * __cdecl CMdaBitmapScaler::NewL(void)
	?NewL@CMdaImageBitmapToBitmapUtility@@SAPAV1@AAVMMdaImageUtilObserver@@PAVCMdaServer@@@Z @ 23 NONAME ; public: static class CMdaImageBitmapToBitmapUtility * __cdecl CMdaImageBitmapToBitmapUtility::NewL(class MMdaImageUtilObserver &,class CMdaServer *)
	?NewL@CMdaImageBitmapToDescUtility@@SAPAV1@AAVMMdaImageUtilObserver@@PAVCMdaServer@@@Z @ 24 NONAME ; public: static class CMdaImageBitmapToDescUtility * __cdecl CMdaImageBitmapToDescUtility::NewL(class MMdaImageUtilObserver &,class CMdaServer *)
	?NewL@CMdaImageBitmapToFileUtility@@SAPAV1@AAVMMdaImageUtilObserver@@PAVCMdaServer@@@Z @ 25 NONAME ; public: static class CMdaImageBitmapToFileUtility * __cdecl CMdaImageBitmapToFileUtility::NewL(class MMdaImageUtilObserver &,class CMdaServer *)
	?NewL@CMdaImageDescToBitmapUtility@@SAPAV1@AAVMMdaImageUtilObserver@@PAVCMdaServer@@@Z @ 26 NONAME ; public: static class CMdaImageDescToBitmapUtility * __cdecl CMdaImageDescToBitmapUtility::NewL(class MMdaImageUtilObserver &,class CMdaServer *)
	?NewL@CMdaImageFileToBitmapUtility@@SAPAV1@AAVMMdaImageUtilObserver@@PAVCMdaServer@@@Z @ 27 NONAME ; public: static class CMdaImageFileToBitmapUtility * __cdecl CMdaImageFileToBitmapUtility::NewL(class MMdaImageUtilObserver &,class CMdaServer *)
	?OpenL@CMdaImageBitmapToBitmapUtility@@QAEXAAVCFbsBitmap@@@Z @ 28 NONAME ; public: void __thiscall CMdaImageBitmapToBitmapUtility::OpenL(class CFbsBitmap &)
	?OpenL@CMdaImageDescToBitmapUtility@@QAEXABVTDesC8@@PAVTMdaClipFormat@@PAVTMdaPackage@@2@Z @ 29 NONAME ; public: void __thiscall CMdaImageDescToBitmapUtility::OpenL(class TDesC8 const &,class TMdaClipFormat *,class TMdaPackage *,class TMdaPackage *)
	?OpenL@CMdaImageFileToBitmapUtility@@QAEXABVTDesC16@@PAVTMdaClipFormat@@PAVTMdaPackage@@2@Z @ 30 NONAME ; public: void __thiscall CMdaImageFileToBitmapUtility::OpenL(class TDesC16 const &,class TMdaClipFormat *,class TMdaPackage *,class TMdaPackage *)
	?RotateL@CMdaBitmapRotator@@QAEXAAVMMdaImageUtilObserver@@AAVCFbsBitmap@@1W4TRotationAngle@1@@Z @ 31 NONAME ; public: void __thiscall CMdaBitmapRotator::RotateL(class MMdaImageUtilObserver &,class CFbsBitmap &,class CFbsBitmap &,enum CMdaBitmapRotator::TRotationAngle)
	?RotateL@CMdaBitmapRotator@@QAEXAAVMMdaImageUtilObserver@@AAVCFbsBitmap@@W4TRotationAngle@1@@Z @ 32 NONAME ; public: void __thiscall CMdaBitmapRotator::RotateL(class MMdaImageUtilObserver &,class CFbsBitmap &,enum CMdaBitmapRotator::TRotationAngle)
	?ScaleL@CMdaBitmapScaler@@QAEXAAVMMdaImageUtilObserver@@AAVCFbsBitmap@@1H@Z @ 33 NONAME ; public: void __thiscall CMdaBitmapScaler::ScaleL(class MMdaImageUtilObserver &,class CFbsBitmap &,class CFbsBitmap &,int)
	?ScaleL@CMdaBitmapScaler@@QAEXAAVMMdaImageUtilObserver@@AAVCFbsBitmap@@VTSize@@H@Z @ 34 NONAME ; public: void __thiscall CMdaBitmapScaler::ScaleL(class MMdaImageUtilObserver &,class CFbsBitmap &,class TSize,int)
	?FrameCommentL@CMdaImageDataReadUtility@@UAEABVTDesC16@@H@Z @ 35 NONAME ; public: virtual class TDesC16 const & __thiscall CMdaImageDataReadUtility::FrameCommentL(int)
	?ImageReadUtilSourcePort_Reserved@@YAXXZ @ 36 NONAME ; void __cdecl ImageReadUtilSourcePort_Reserved(void)
